@@ -1,9 +1,8 @@
 context("grid_state_correspondence_table")
 
 # skip tests because they take too much time
+skip_if(Sys.getenv("TEST_ONE") != "")
 testthat::skip_on_cran()
-# testthat::skip_on_travis()
-# skip_if(Sys.getenv("TEST_ONE") != "")
 
 test_that("grid_state_correspondence_table", {
 
